/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef COMMON_STRING_ARRAY_H
#define COMMON_STRING_ARRAY_H

#include "common/array.h"
#include "common/str.h"
#include "common/ustr.h"

namespace Common {

/**
 * @defgroup common_str_array String array
 * @ingroup common_str
 *
 * @brief String array implementation.
 *
 * @{
 */

/**
 * An array of of strings.
 */
typedef Array<String>		StringArray;
typedef Array<U32String>	U32StringArray;

/** @} */

} // End of namespace Common

#endif
